Struct PhysHandoff
Source #[repr(C)]
pub struct PhysHandoff {Show 27 fields
pub magic: u64,
pub times: PhysBootTimes,
pub init_array: __BindgenOpaqueArray8<[u8; 16]>,
pub vmars: __BindgenOpaqueArray8<[u8; 16]>,
pub temporary_vmar: __BindgenOpaqueArray8<[u8; 8]>,
pub physmap_base: usize,
pub physmap_size: usize,
pub zbi: PhysVmo,
pub vdso: PhysElfImage,
pub userboot: PhysElfImage,
pub extra_vmos: __BindgenOpaqueArray8<[u8; 16]>,
pub entropy_pool: __BindgenOpaqueArray<[u8; 33]>,
pub arch_handoff: ArchPhysHandoff,
pub memory: __BindgenOpaqueArray8<[u8; 16]>,
pub cpu_topology: __BindgenOpaqueArray8<[u8; 16]>,
pub crashlog: PhysHandoffTemporaryString,
pub nvram: __BindgenOpaqueArray8<[u8; 16]>,
pub platform_id: Optional<zbi_platform_id_t>,
pub acpi_rsdp: Optional<u64>,
pub smbios_phys: Optional<u64>,
pub efi_memory_attributes: __BindgenOpaqueArray8<[u8; 16]>,
pub efi_system_table: Optional<u64>,
pub uart: uart_all_Driver,
pub uart_mmio: MappedMmioRange,
pub mmio_deny: __BindgenOpaqueArray8<[u8; 16]>,
pub periph_ranges: __BindgenOpaqueArray8<[u8; 16]>,
pub heap_vmar: __BindgenOpaqueArray8<[u8; 72]>,
}
arch_handoff: ArchPhysHandoff
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.